/**************************************************************************//**
* @file
* @brief Trace buffer for debug
* @version 3.20.3
******************************************************************************
* @section License
* <b>(C) Copyright 2014 Silicon Labs, http://www.silabs.com</b>
*******************************************************************************
*
* This file is licensed under the Silabs License Agreement. See the file
* "Silabs_License_Agreement.txt" for details. Before using this software for
* any purpose, you must agree to the terms of that agreement.
*
******************************************************************************/

#include <stdint.h>
#include "Trace.h"


#if TRACE_INCLUDE == 1

uint8_t *pTrace;
uint8_t *pTraceLimit;
uint8_t TraceBuff[TRACE_BUFF_SIZE];


/**************************************************************************//**
 * @brief  TraceInit initializes the debug buffer
 *****************************************************************************/
void TraceInit(void)
{
  pTraceLimit = &TraceBuff[TRACE_BUFF_SIZE];

  for (pTrace = TraceBuff; pTrace < pTraceLimit; pTrace++)
    *pTrace = 0;

  pTrace = TraceBuff;
}


/**************************************************************************//**
 * @brief  TraceByte puts a byte in the debug buffer
 *****************************************************************************/
void TraceByte(uint8_t Byte)
{
  *pTrace++ = Byte;

  if (pTrace == pTraceLimit)
    pTrace = TraceBuff;
}


/**************************************************************************//**
 * @brief  TraceWord puts a word in the debug buffer
 *****************************************************************************/
void TraceWord(uint16_t Word)
{
  TraceByte((Word >> 8) & 0xFF);
  TraceByte(Word & 0xFF);
}


/**************************************************************************//**
 * @brief  TraceDWord puts a 32 byte value in the debug buffer
 *****************************************************************************/
void TraceDWord(uint32_t DWord)
{
  TraceWord((DWord >> 16) & 0xFFFF);
  TraceWord(DWord & 0xFFFF);
}
#endif


